@@ -15,12 +15,12 @@ fn main() {
         "Pineapple",
     ];
 
-    let validator: MultiOptionValidator = &|a| {
+    let validator: MultiOptionValidator<&str> = &|a| {
         if a.len() < 2 {
             return Err("This list is too small!".into());
         }
 
-        let x = a.iter().any(|o| o.value == "Pineapple");
+        let x = a.iter().any(|o| *o.value == "Pineapple");
 
         match x {
             true => Ok(()),
@@ -28,9 +28,9 @@ fn main() {
         }
     };
 
-    let formatter: MultiOptionFormatter = &|a| format!("{} different fruits", a.len());
+    let formatter: MultiOptionFormatter<&str> = &|a| format!("{} different fruits", a.len());
 
-    let ans = MultiSelect::new("Select the fruits for your shopping list:", &options)
+    let ans = MultiSelect::new("Select the fruits for your shopping list:", options)
         .with_validator(validator)
         .with_formatter(formatter)
         .prompt();
