@@ -5,6 +5,7 @@ use std::{
 };
 
 use crate::{
+    config::get_configuration,
     date_utils::{get_current_date, get_month},
     error::{InquireError, InquireResult},
     formatter::{self, DateFormatter},
@@ -98,7 +99,7 @@ pub struct DateSelect<'a> {
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub render_config: &'a RenderConfig,
+    pub render_config: RenderConfig,
 }
 
 impl<'a> DateSelect<'a> {
@@ -136,7 +137,7 @@ impl<'a> DateSelect<'a> {
             formatter: Self::DEFAULT_FORMATTER,
             validators: Self::DEFAULT_VALIDATORS,
             week_start: Self::DEFAULT_WEEK_START,
-            render_config: RenderConfig::default_static_ref(),
+            render_config: get_configuration(),
         }
     }
 
@@ -223,7 +224,7 @@ impl<'a> DateSelect<'a> {
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub fn with_render_config(mut self, render_config: &'a RenderConfig) -> Self {
+    pub fn with_render_config(mut self, render_config: RenderConfig) -> Self {
         self.render_config = render_config;
         self
     }
@@ -469,8 +470,7 @@ mod test {
 
                 let mut write: Vec<u8> = Vec::new();
                 let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-                let mut backend =
-                    Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+                let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
                 let ans = $prompt.prompt_with_backend(&mut backend).unwrap();
 
@@ -510,7 +510,7 @@ mod test {
 
         let mut write: Vec<u8> = Vec::new();
         let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-        let mut backend = Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+        let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
         let ans = DateSelect::new("Question")
             .with_validator(&validator)
