@@ -1,12 +1,13 @@
 use std::{collections::BTreeSet, fmt::Display};
 
 use crate::{
-    config::{self, Filter},
+    config::{self, get_configuration},
     error::{InquireError, InquireResult},
     formatter::MultiOptionFormatter,
     input::Input,
     list_option::ListOption,
     terminal::get_default_terminal,
+    type_aliases::Filter,
     ui::{Backend, Key, KeyModifiers, MultiSelectBackend, RenderConfig},
     utils::paginate,
     validator::MultiOptionValidator,
@@ -89,7 +90,7 @@ pub struct MultiSelect<'a, T> {
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub render_config: &'a RenderConfig,
+    pub render_config: RenderConfig,
 }
 
 impl<'a, T> MultiSelect<'a, T>
@@ -182,7 +183,7 @@ where
             filter: Self::DEFAULT_FILTER,
             formatter: Self::DEFAULT_FORMATTER,
             validator: None,
-            render_config: RenderConfig::default_static_ref(),
+            render_config: get_configuration(),
         }
     }
 
@@ -258,7 +259,7 @@ where
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub fn with_render_config(mut self, render_config: &'a RenderConfig) -> Self {
+    pub fn with_render_config(mut self, render_config: RenderConfig) -> Self {
         self.render_config = render_config;
         self
     }
@@ -617,7 +618,7 @@ mod test {
 
         let mut write: Vec<u8> = Vec::new();
         let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-        let mut backend = Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+        let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
         let ans = MultiSelect::new("Question", options)
             .with_formatter(formatter)
@@ -649,7 +650,7 @@ mod test {
 
         let mut write: Vec<u8> = Vec::new();
         let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-        let mut backend = Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+        let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
         let ans = MultiSelect::new("Question", options)
             .prompt_with_backend(&mut backend)
@@ -677,7 +678,7 @@ mod test {
 
         let mut write: Vec<u8> = Vec::new();
         let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-        let mut backend = Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+        let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
         let ans = MultiSelect::new("Question", options)
             .prompt_with_backend(&mut backend)
