@@ -1,12 +1,13 @@
 use std::cmp::min;
 
 use crate::{
-    config::{self, Suggester},
+    config::{self, get_configuration},
     error::{InquireError, InquireResult},
     formatter::{StringFormatter, DEFAULT_STRING_FORMATTER},
     input::Input,
     list_option::ListOption,
     terminal::get_default_terminal,
+    type_aliases::Suggester,
     ui::{Backend, Key, KeyModifiers, RenderConfig, TextBackend},
     utils::paginate,
     validator::StringValidator,
@@ -98,7 +99,7 @@ pub struct Text<'a> {
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub render_config: &'a RenderConfig,
+    pub render_config: RenderConfig,
 }
 
 impl<'a> Text<'a> {
@@ -125,7 +126,7 @@ impl<'a> Text<'a> {
             formatter: Self::DEFAULT_FORMATTER,
             page_size: Self::DEFAULT_PAGE_SIZE,
             suggester: None,
-            render_config: RenderConfig::default_static_ref(),
+            render_config: get_configuration(),
         }
     }
 
@@ -201,7 +202,7 @@ impl<'a> Text<'a> {
     /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
     /// config is treated as the only source of truth. If you want to customize colors
     /// and still suport NO_COLOR, you will have to do this on your end.
-    pub fn with_render_config(mut self, render_config: &'a RenderConfig) -> Self {
+    pub fn with_render_config(mut self, render_config: RenderConfig) -> Self {
         self.render_config = render_config;
         self
     }
@@ -467,8 +468,7 @@ mod test {
                 let mut write: Vec<u8> = Vec::new();
 
                 let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
-                let mut backend =
-                    Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+                let mut backend = Backend::new(terminal, RenderConfig::default()).unwrap();
 
                 let ans = $prompt.prompt_with_backend(&mut backend).unwrap();
 
