@@ -79,7 +79,7 @@ impl Default for Position {
     }
 }
 
-pub struct Backend<'a, T>
+pub struct Backend<T>
 where
     T: Terminal,
 {
@@ -90,14 +90,14 @@ where
     show_cursor: bool,
     terminal: T,
     terminal_size: TerminalSize,
-    render_config: &'a RenderConfig,
+    render_config: RenderConfig,
 }
 
-impl<'a, T> Backend<'a, T>
+impl<T> Backend<T>
 where
     T: Terminal,
 {
-    pub fn new(terminal: T, render_config: &'a RenderConfig) -> Result<Self> {
+    pub fn new(terminal: T, render_config: RenderConfig) -> Result<Self> {
         let terminal_size = terminal.get_size().unwrap_or(TerminalSize {
             width: 1000,
             height: 1000,
@@ -181,7 +181,7 @@ where
         let position = current.chars().count();
         let position = position.saturating_add(offset);
 
-        self.prompt_cursor_offset.insert(position);
+        self.prompt_cursor_offset = Some(position);
     }
 
     fn reset_prompt(&mut self) -> Result<()> {
@@ -226,13 +226,13 @@ where
         let empty_prefix = Styled::new(" ");
 
         let x = if idx == page.selection {
-            &self.render_config.highlighted_option_prefix
+            self.render_config.highlighted_option_prefix
         } else if idx == 0 && !page.first {
-            &self.render_config.scroll_up_prefix
+            self.render_config.scroll_up_prefix
         } else if (idx + 1) == page.content.len() && !page.last {
-            &self.render_config.scroll_down_prefix
+            self.render_config.scroll_down_prefix
         } else {
-            &empty_prefix
+            empty_prefix
         };
 
         self.terminal.write_styled(&x)
@@ -345,7 +345,7 @@ where
     }
 }
 
-impl<'a, T> CommonBackend for Backend<'a, T>
+impl<T> CommonBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -437,7 +437,7 @@ where
     }
 }
 
-impl<'a, T> TextBackend for Backend<'a, T>
+impl<T> TextBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -466,7 +466,7 @@ where
 }
 
 #[cfg(feature = "editor")]
-impl<'a, T> EditorBackend for Backend<'a, T>
+impl<T> EditorBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -485,7 +485,7 @@ where
     }
 }
 
-impl<'a, T> SelectBackend for Backend<'a, T>
+impl<T> SelectBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -516,7 +516,7 @@ where
     }
 }
 
-impl<'a, T> MultiSelectBackend for Backend<'a, T>
+impl<T> MultiSelectBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -586,7 +586,7 @@ pub mod date {
         ) -> Result<()>;
     }
 
-    impl<'a, T> DateSelectBackend for Backend<'a, T>
+    impl<T> DateSelectBackend for Backend<T>
     where
         T: Terminal,
     {
@@ -710,7 +710,7 @@ pub mod date {
     }
 }
 
-impl<'a, T> CustomTypeBackend for Backend<'a, T>
+impl<T> CustomTypeBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -724,7 +724,7 @@ where
     }
 }
 
-impl<'a, T> PasswordBackend for Backend<'a, T>
+impl<T> PasswordBackend for Backend<T>
 where
     T: Terminal,
 {
@@ -749,7 +749,7 @@ where
     }
 }
 
-impl<'a, T> Drop for Backend<'a, T>
+impl<T> Drop for Backend<T>
 where
     T: Terminal,
 {
