@@ -1,7 +1,5 @@
 use std::env;
 
-use lazy_static::lazy_static;
-
 use super::{Color, StyleSheet, Styled};
 
 /// Rendering configuration that can be applied to a prompt.
@@ -18,12 +16,10 @@ use super::{Color, StyleSheet, Styled};
 /// let empty: RenderConfig = RenderConfig::empty();
 /// let default: RenderConfig = RenderConfig::default();
 ///
-/// let default_used_in_prompts: &'static RenderConfig = RenderConfig::default_static_ref();
-///
 /// let prompt_prefix = Styled::new("$").with_fg(Color::DarkRed);
 /// let mine = default.with_prompt_prefix(prompt_prefix);
 /// ```
-#[derive(Clone, Debug)]
+#[derive(Copy, Clone, Debug)]
 pub struct RenderConfig {
     /// Prefix added before prompts.
     ///
@@ -198,24 +194,6 @@ impl RenderConfig {
         }
     }
 
-    /// Static reference to a [default](crate::ui::RenderConfig::default) render configuration.
-    pub fn default_static_ref() -> &'static Self {
-        lazy_static! {
-            static ref DEFAULT_RENDER_CONFIG: RenderConfig = RenderConfig::default();
-        };
-
-        &DEFAULT_RENDER_CONFIG
-    }
-
-    /// Static reference to an [empty](crate::ui::RenderConfig::empty) render configuration.
-    pub fn empty_static_ref() -> &'static Self {
-        lazy_static! {
-            static ref EMPTY_RENDER_CONFIG: RenderConfig = RenderConfig::empty();
-        };
-
-        &EMPTY_RENDER_CONFIG
-    }
-
     /// Sets the prompt prefix and its style sheet.
     pub fn with_prompt_prefix(mut self, prompt_prefix: Styled<&'static str>) -> Self {
         self.prompt_prefix = prompt_prefix;
@@ -369,7 +347,7 @@ pub enum IndexPrefix {
 }
 
 /// Render configuration for error messages.
-#[derive(Clone, Debug)]
+#[derive(Copy, Clone, Debug)]
 pub struct ErrorMessageRenderConfig {
     /// Prefix style.
     pub prefix: Styled<&'static str>,
@@ -432,7 +410,7 @@ pub mod calendar {
     use super::{Color, StyleSheet, Styled};
 
     /// Calendar configuration for error messages.
-    #[derive(Clone, Debug)]
+    #[derive(Copy, Clone, Debug)]
     pub struct CalendarRenderConfig {
         /// Prefix style.
         pub prefix: Styled<&'static str>,
